@@ -34,7 +34,7 @@ has logger =>
 
 use namespace::autoclean;
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 # -----------------------------------------------
 
@@ -68,6 +68,19 @@ sub BUILD
 
 # -----------------------------------------------
 
+sub format_amount
+{
+	my($self, $amount, $currency) = @_;
+	my($decimal_places) = $currency -> decimal_places;
+	my($symbol_left)    = $currency -> symbol_left;
+	my($format)         = sprintf('%s%%.%sf', $symbol_left, $decimal_places);
+
+	return sprintf($format, $amount),
+
+} # End of format_amount.
+
+# -----------------------------------------------
+
 __PACKAGE__ -> meta -> make_immutable;
 
 1;
