@@ -3,7 +3,6 @@ package Business::Cart::Generic::View;
 use strict;
 use warnings;
 
-use Business::Cart::Generic::View::Add;
 use Business::Cart::Generic::View::Order;
 use Business::Cart::Generic::View::Product;
 use Business::Cart::Generic::View::Search;
@@ -12,12 +11,6 @@ use Moose;
 
 extends 'Business::Cart::Generic::View::Base';
 
-has add =>
-(
- is  => 'rw',
- isa => 'Business::Cart::Generic::View::Add',
-);
-
 has order =>
 (
  is  => 'rw',
@@ -38,7 +31,7 @@ has search =>
 
 use namespace::autoclean;
 
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 # -----------------------------------------------
 
@@ -46,19 +39,11 @@ sub BUILD
 {
 	my($self) = @_;
 
-	$self -> add
-		(
-		 Business::Cart::Generic::View::Add -> new
-		 (
-		  db        => $self -> db,
-		  templater => $self -> templater,
-		 )
-		);
-
 	$self -> order
 		(
 		 Business::Cart::Generic::View::Order -> new
 		 (
+		  config    => $self -> config,
 		  db        => $self -> db,
 		  templater => $self -> templater,
 		 )
@@ -68,6 +53,7 @@ sub BUILD
 		(
 		 Business::Cart::Generic::View::Product -> new
 		 (
+		  config    => $self -> config,
 		  db        => $self -> db,
 		  templater => $self -> templater,
 		 )
@@ -77,6 +63,7 @@ sub BUILD
 		(
 		 Business::Cart::Generic::View::Search -> new
 		 (
+		  config    => $self -> config,
 		  db        => $self -> db,
 		  templater => $self -> templater,
 		 )
